pub enum EventFocusThreadMode {
ForceThread,
Automatic,
}Expand description
Options for controlling the behaviour of an EventFocusedCache when the
focused event may be part of a thread, or a thread’s root.
Variants
ForceThread
Force the timeline represented by the linked chunk to only include threaded events.
When the focused event is part of a thread, the linked chunk will be focused on that thread’s root. Otherwise, the linked chunk will treat the target event itself as the thread root. Threaded events will never be hidden.
Automatic
Automatically determine if the target event is part of a thread or not.
If the event is part of a thread, the linked chunk will be filtered to on-thread events.