pub struct EventCacheConfig {
pub max_pinned_events_concurrent_requests: usize,
pub max_pinned_events_to_load: usize,
pub max_concurrent_back_paginations: NonZeroUsize,
}Expand description
Global configuration for the EventCache, applied to every single room.
Fields
max_pinned_events_concurrent_requests: usizeMaximum number of concurrent /event requests when loading pinned events.
max_pinned_events_to_load: usizeMaximum number of pinned events to load, for any room.
max_concurrent_back_paginations: NonZeroUsizeThe maximum number of back-paginations the background queue runs at once, across all rooms and use cases. Bounds server load.
Defaults to
EventCacheConfig::DEFAULT_MAX_CONCURRENT_BACK_PAGINATIONS.
Implementations
Sourceimpl EventCacheConfig
impl EventCacheConfig
Sourcepub const DEFAULT_MAX_EVENTS_TO_LOAD: usize = 128
pub const DEFAULT_MAX_EVENTS_TO_LOAD: usize = 128
The default maximum number of pinned events to load.
Sourcepub const DEFAULT_MAX_CONCURRENT_REQUESTS: usize = 8
pub const DEFAULT_MAX_CONCURRENT_REQUESTS: usize = 8
The default maximum number of concurrent requests to perform when loading the pinned events.
Sourcepub const DEFAULT_MAX_CONCURRENT_BACK_PAGINATIONS: NonZeroUsize
pub const DEFAULT_MAX_CONCURRENT_BACK_PAGINATIONS: NonZeroUsize
The default maximum number of concurrent background back-paginations
(see also EventCacheConfig::max_concurrent_back_paginations).