pub struct RoomEventCache { /* private fields */ }Expand description
A subset of an event cache, for a room.
Cloning is shallow, and thus is cheap to do.
Implementations
Sourceimpl RoomEventCache
impl RoomEventCache
Sourcepub fn room_id(&self) -> &RoomId
pub fn room_id(&self) -> &RoomId
Get the room ID for this RoomEventCache.
Sourcepub async fn events(&self) -> Result<Vec<Event>>
pub async fn events(&self) -> Result<Vec<Event>>
Read all current events.
Use RoomEventCache::subscribe to get all current events, plus a
subscriber.
Sourcepub async fn subscribe(
&self,
) -> Result<(Vec<Event>, Subscriber<RoomEventCacheUpdate>)>
pub async fn subscribe( &self, ) -> Result<(Vec<Event>, Subscriber<RoomEventCacheUpdate>)>
Subscribe to this room updates, after getting the initial list of events.
Use RoomEventCache::events to get all current events without the
subscriber. Creating, and especially dropping, a Subscriber isn’t
free, as it triggers side-effects.
Sourcepub fn pagination(&self) -> RoomPagination
pub fn pagination(&self) -> RoomPagination
Return a RoomPagination type useful for running back-pagination
queries in the current room.
Sourcepub async fn rfind_map_event_in_memory_by<O, P>(
&self,
predicate: P,
) -> Result<Option<O>>
pub async fn rfind_map_event_in_memory_by<O, P>( &self, predicate: P, ) -> Result<Option<O>>
Try to find a single event in this room, starting from the most recent event.
The predicate receives the current event as its single argument.
Warning! It looks into the loaded events from the in-memory linked chunk only. It doesn’t look inside the storage.
Sourcepub async fn find_event(&self, event_id: &EventId) -> Result<Option<Event>>
pub async fn find_event(&self, event_id: &EventId) -> Result<Option<Event>>
Try to find an event by ID in this room.
It starts by looking into loaded events before looking inside the storage.
Sourcepub async fn find_event_with_relations(
&self,
event_id: &EventId,
filter: Option<Vec<RelationType>>,
) -> Result<Option<(Event, Vec<Event>)>>
pub async fn find_event_with_relations( &self, event_id: &EventId, filter: Option<Vec<RelationType>>, ) -> Result<Option<(Event, Vec<Event>)>>
Try to find an event by ID in this room, along with its related events.
You can filter which types of related events to retrieve using
filter. None will retrieve related events of any type.
The related events are sorted like this:
- events saved out-of-band (with
RoomEventCache::save_events) will be located at the beginning of the array. - events present in the linked chunk (be it in memory or in the storage) will be sorted according to their ordering in the linked chunk.
Sourcepub async fn find_event_relations(
&self,
event_id: &EventId,
filter: Option<Vec<RelationType>>,
) -> Result<Vec<Event>>
pub async fn find_event_relations( &self, event_id: &EventId, filter: Option<Vec<RelationType>>, ) -> Result<Vec<Event>>
Try to find the related events for an event by ID in this room.
You can filter which types of related events to retrieve using
filter. None will retrieve related events of any type.
The related events are sorted like this:
- events saved out-of-band (with
RoomEventCache::save_events) will be located at the beginning of the array. - events present in the linked chunk (be it in memory or in the storage) will be sorted according to their ordering in the linked chunk.
Sourcepub async fn debug_string(&self) -> Vec<String>
pub async fn debug_string(&self) -> Vec<String>
Return a nice debug string (a vector of lines) for the linked chunk of events for this room.