pub struct ThreadEventCache { /* private fields */ }Expand description
All the information related to a single thread.
Cloning is shallow, and thus is cheap to do.
Implementations
Sourceimpl ThreadEventCache
impl ThreadEventCache
Sourcepub async fn num_unread_messages(&self) -> Result<u64>
pub async fn num_unread_messages(&self) -> Result<u64>
Get the number of unread messages.
To get multiple information about the read receipts, use
Self::read_receipts as it involves a single lock.
Sourcepub async fn num_unread_notifications(&self) -> Result<u64>
pub async fn num_unread_notifications(&self) -> Result<u64>
Get the number of unread notifications.
To get multiple information about the read receipts, use
Self::read_receipts as it involves a single lock.
Sourcepub async fn num_unread_mentions(&self) -> Result<u64>
pub async fn num_unread_mentions(&self) -> Result<u64>
Get the number of unread mentions, that is, messages causing a highlight in a room.
To get multiple information about the read receipts, use
Self::read_receipts as it involves a single lock.
Sourcepub async fn read_receipts(&self) -> Result<ReadReceipts>
pub async fn read_receipts(&self) -> Result<ReadReceipts>
Get the detailed information about read receipts for this thread.
Sourcepub async fn subscribe_to_thread_info(
&self,
) -> Result<Subscriber<ThreadInfo, AsyncLock>>
pub async fn subscribe_to_thread_info( &self, ) -> Result<Subscriber<ThreadInfo, AsyncLock>>
Subscribe to update of the ThreadInfo.
Sourcepub async fn subscribe(
&self,
) -> Result<(Vec<Event>, Subscriber<ThreadEventCacheUpdate>)>
pub async fn subscribe( &self, ) -> Result<(Vec<Event>, Subscriber<ThreadEventCacheUpdate>)>
Subscribe to this thread updates, after getting the initial list of events.
Creating, and especially dropping, a Subscriber isn’t free, as it
triggers side-effects.
Sourcepub fn pagination(&self) -> ThreadPagination
pub fn pagination(&self) -> ThreadPagination
Return a ThreadPagination useful for running back-pagination queries
in this thread.
Sourcepub async fn find_event_with_relations(
&self,
event_id: &EventId,
filter: Option<Vec<RelationType>>,
) -> Result<Option<(Event, Vec<Event>)>>
pub async fn find_event_with_relations( &self, event_id: &EventId, filter: Option<Vec<RelationType>>, ) -> Result<Option<(Event, Vec<Event>)>>
Try to find an event by ID in this thread, along with its related events.
You can filter which types of related events to retrieve using
filter. None will retrieve related events of any type.
The related events are sorted like this:
- events saved out-of-band (with
RoomEventCache::save_events) will be located at the beginning of the array. - events present in the linked chunk (be it in memory or in the storage) will be sorted according to their ordering in the linked chunk.