pub struct EventCacheConfig {
pub max_pinned_events_concurrent_requests: usize,
pub max_pinned_events_to_load: usize,
pub experimental_auto_backpagination: bool,
pub room_pagination_per_room_credit: usize,
pub room_pagination_batch_size: u16,
}Expand description
Global configuration for the EventCache, applied to every single room.
Fields
max_pinned_events_concurrent_requests: usizeMaximum number of concurrent /event requests when loading pinned events.
max_pinned_events_to_load: usizeMaximum number of pinned events to load, for any room.
experimental_auto_backpagination: boolWhether to automatically backpaginate a room under certain conditions.
Off by default.
room_pagination_per_room_credit: usizeThe maximum number of allowed room paginations, for a given room, that can be executed in the automatic paginations task.
After that number of paginations, the task will stop executing paginations for that room in the background (user-requested paginations will still be executed, of course).
Defaults to EventCacheConfig::DEFAULT_ROOM_PAGINATION_CREDITS.
room_pagination_batch_size: u16The number of messages to paginate in a single batch, when executing an automatic pagination request.
Defaults to EventCacheConfig::DEFAULT_ROOM_PAGINATION_BATCH_SIZE.
Implementations
Sourceimpl EventCacheConfig
impl EventCacheConfig
Sourcepub const DEFAULT_MAX_EVENTS_TO_LOAD: usize = 128
pub const DEFAULT_MAX_EVENTS_TO_LOAD: usize = 128
The default maximum number of pinned events to load.
Sourcepub const DEFAULT_MAX_CONCURRENT_REQUESTS: usize = 8
pub const DEFAULT_MAX_CONCURRENT_REQUESTS: usize = 8
The default maximum number of concurrent requests to perform when loading the pinned events.
Sourcepub const DEFAULT_ROOM_PAGINATION_CREDITS: usize = 20
pub const DEFAULT_ROOM_PAGINATION_CREDITS: usize = 20
The default number of credits to give to a room for automatic
paginations (see also
EventCacheConfig::room_pagination_per_room_credit).
Sourcepub const DEFAULT_ROOM_PAGINATION_BATCH_SIZE: u16 = 30
pub const DEFAULT_ROOM_PAGINATION_BATCH_SIZE: u16 = 30
The default number of messages to paginate in a single batch, when
executing an automatic pagination request (see also
EventCacheConfig::room_pagination_batch_size).