ThreadEventCache

Struct ThreadEventCache 

pub struct ThreadEventCache { /* private fields */ }
All the information related to a single thread.

Cloning is shallow, and thus is cheap to do.

Implementations

Source

impl ThreadEventCache

pub fn room_id(&self) -> &RoomId

Get the room ID for this room.

pub fn thread_id(&self) -> &EventId

Get the thread ID for this thread.

pub async fn subscribe( &self, ) -> Result<(Vec<Event>, Receiver<TimelineVectorDiffs>)>

Subscribe to live events from this thread.

pub fn pagination(&self) -> ThreadPagination

Return a ThreadPagination useful for running back-pagination queries in this thread.

pub async fn find_event_with_relations( &self, event_id: &EventId, filter: Option<Vec<RelationType>>, ) -> Result<Option<(Event, Vec<Event>)>>

Try to find an event by ID in this thread, along with its related events.

You can filter which types of related events to retrieve using filter. None will retrieve related events of any type.

The related events are sorted like this:

  • events saved out-of-band (with RoomEventCache::save_events) will be located at the beginning of the array.
  • events present in the linked chunk (be it in memory or in the storage) will be sorted according to their ordering in the linked chunk.